_`umbra.components.addons.projectsExplorer.projectsExplorer`
============================================================

.. automodule:: umbra.components.addons.projectsExplorer.projectsExplorer

Module Attributes
-----------------

.. attribute:: umbra.components.addons.projectsExplorer.projectsExplorer.LOGGER

.. attribute:: umbra.components.addons.projectsExplorer.projectsExplorer.COMPONENT_UI_FILE

Classes
-------

.. autoclass:: ProjectsExplorer
	:show-inheritance:
	:members:

